@@ -21,7 +21,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -592,7 +592,7 @@ RDF::LDF - Linked Data Fragments client
 =begin markdown
 
 # STATUS
-[![Build Status](https://travis-ci.org/phochste/RDF-LDF.png)](https://travis-ci.org/phochste/RDF-LDF)
+[![Build Status](https://travis-ci.org/phochste/RDF-LDF.svg)](https://travis-ci.org/phochste/RDF-LDF)
 [![Coverage Status](https://coveralls.io/repos/phochste/RDF-LDF/badge.svg)](https://coveralls.io/r/phochste/RDF-LDF)
 [![Kwalitee Score](http://cpants.cpanauthors.org/dist/RDF-LDF.png)](http://cpants.cpanauthors.org/dist/RDF-LDF)
 
@@ -665,7 +665,7 @@ Patrick Hochstenbach, C<< patrick.hochstenbach at ugent.be >>
 
 Gregory Todd Williams, C<< greg@evilfunhouse.com >>
 
-Jacob Voss, C<<voss@gbv.de>>
+Jacob Voss, C<< voss@gbv.de >>
 
 =head1 COPYRIGHT AND LICENSE
 
